/*
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
import { Component, Input } from '@angular/core';
import { Spinkit } from '../spinkits';
import { PendingInterceptorService } from '../pending-interceptor.service';
export class SpinnerComponent {
    constructor(pendingRequestInterceptorService) {
        this.pendingRequestInterceptorService = pendingRequestInterceptorService;
        this.Spinkit = Spinkit;
        this.spinner = Spinkit.skCubeGrid;
        this.filteredUrlPatterns = [];
        this.subscription = this.pendingRequestInterceptorService
            .pendingRequestsStatus
            .subscribe(hasPendingRequests => {
            this.isSpinnerVisible = hasPendingRequests;
        });
    }
    ngOnInit() {
        if (!(this.filteredUrlPatterns instanceof Array)) {
            throw new TypeError('`filteredUrlPatterns` must be an array.');
        }
        if (!!this.filteredUrlPatterns.length) {
            this.filteredUrlPatterns.forEach(e => {
                this.pendingRequestInterceptorService.filteredUrlPatterns.push(new RegExp(e));
            });
        }
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
}
SpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'spinner',
                template: `
      <div id="spinner" *ngIf="isSpinnerVisible">

              <sk-cube-grid
                  *ngIf="spinner === Spinkit.skCubeGrid"
                  [backgroundColor]="backgroundColor">
              </sk-cube-grid>

              <sk-chasing-dots
                  *ngIf="spinner === Spinkit.skChasingDots"
                  [backgroundColor]="backgroundColor">
              </sk-chasing-dots>

              <sk-double-bounce
                  *ngIf="spinner === Spinkit.skDoubleBounce"
                  [backgroundColor]="backgroundColor">
              </sk-double-bounce>

              <sk-rotating-plane
                  *ngIf="spinner === Spinkit.skRotatingPlane"
                  [backgroundColor]="backgroundColor">
              </sk-rotating-plane>

              <sk-spinner-pulse
                  *ngIf="spinner === Spinkit.skSpinnerPulse"
                  [backgroundColor]="backgroundColor">
              </sk-spinner-pulse>

              <sk-three-bounce
                  *ngIf="spinner === Spinkit.skThreeBounce"
                  [backgroundColor]="backgroundColor">
              </sk-three-bounce>

              <sk-wandering-cubes
                  *ngIf="spinner === Spinkit.skWanderingCubes"
                  [backgroundColor]="backgroundColor">
              </sk-wandering-cubes>

              <sk-wave
                  *ngIf="spinner === Spinkit.skWave"
                  [backgroundColor]="backgroundColor">
              </sk-wave>

      </div>
    `,
                styles: [`
      #spinner {
          top: 0;
          left: 0;
          height: 100%;
          width: 100%;
          position: fixed;
          z-index: 9999;
          filter: alpha(opacity=70);
          opacity: .7;
          background-color: #f1f1f1;
          display: flex;
          align-items: center;
          justify-content: center;
      }

      .colored-parent, .colored > div {
          background-color: #333;
      }
    `]
            },] },
];
/** @nocollapse */
SpinnerComponent.ctorParameters = () => [
    { type: PendingInterceptorService, },
];
SpinnerComponent.propDecorators = {
    'backgroundColor': [{ type: Input },],
    'spinner': [{ type: Input },],
    'filteredUrlPatterns': [{ type: Input },],
};
//# sourceMappingURL=spinner.component.js.map